@@ -51,8 +51,10 @@ class TextToSpeechGrpcAsyncIOTransport(TextToSpeechTransport):
         cls,
         host: str = "texttospeech.googleapis.com",
         credentials: credentials.Credentials = None,
+        credentials_file: Optional[str] = None,
         scopes: Optional[Sequence[str]] = None,
-        **kwargs
+        quota_project_id: Optional[str] = None,
+        **kwargs,
     ) -> aio.Channel:
         """Create and return a gRPC AsyncIO channel object.
         Args:
@@ -62,9 +64,14 @@ class TextToSpeechGrpcAsyncIOTransport(TextToSpeechTransport):
                 credentials identify this application to the service. If
                 none are specified, the client will attempt to ascertain
                 the credentials from the environment.
+            credentials_file (Optional[str]): A file with credentials that can
+                be loaded with :func:`google.auth.load_credentials_from_file`.
+                This argument is ignored if ``channel`` is provided.
             scopes (Optional[Sequence[str]]): A optional list of scopes needed for this
                 service. These are only used when credentials are not specified and
                 are passed to :func:`google.auth.default`.
+            quota_project_id (Optional[str]): An optional project to use for billing
+                and quota.
             kwargs (Optional[dict]): Keyword arguments, which are passed to the
                 channel creation.
         Returns:
@@ -72,7 +79,12 @@ class TextToSpeechGrpcAsyncIOTransport(TextToSpeechTransport):
         """
         scopes = scopes or cls.AUTH_SCOPES
         return grpc_helpers_async.create_channel(
-            host, credentials=credentials, scopes=scopes, **kwargs
+            host,
+            credentials=credentials,
+            credentials_file=credentials_file,
+            scopes=scopes,
+            quota_project_id=quota_project_id,
+            **kwargs,
         )
 
     def __init__(
@@ -80,9 +92,12 @@ class TextToSpeechGrpcAsyncIOTransport(TextToSpeechTransport):
         *,
         host: str = "texttospeech.googleapis.com",
         credentials: credentials.Credentials = None,
+        credentials_file: Optional[str] = None,
+        scopes: Optional[Sequence[str]] = None,
         channel: aio.Channel = None,
         api_mtls_endpoint: str = None,
-        client_cert_source: Callable[[], Tuple[bytes, bytes]] = None
+        client_cert_source: Callable[[], Tuple[bytes, bytes]] = None,
+        quota_project_id=None,
     ) -> None:
         """Instantiate the transport.
 
@@ -94,6 +109,12 @@ class TextToSpeechGrpcAsyncIOTransport(TextToSpeechTransport):
                 are specified, the client will attempt to ascertain the
                 credentials from the environment.
                 This argument is ignored if ``channel`` is provided.
+            credentials_file (Optional[str]): A file with credentials that can
+                be loaded with :func:`google.auth.load_credentials_from_file`.
+                This argument is ignored if ``channel`` is provided.
+            scopes (Optional[Sequence[str]]): A optional list of scopes needed for this
+                service. These are only used when credentials are not specified and
+                are passed to :func:`google.auth.default`.
             channel (Optional[aio.Channel]): A ``Channel`` instance through
                 which to make calls.
             api_mtls_endpoint (Optional[str]): The mutual TLS endpoint. If
@@ -104,10 +125,14 @@ class TextToSpeechGrpcAsyncIOTransport(TextToSpeechTransport):
                 callback to provide client SSL certificate bytes and private key
                 bytes, both in PEM format. It is ignored if ``api_mtls_endpoint``
                 is None.
+            quota_project_id (Optional[str]): An optional project to use for billing
+                and quota.
 
         Raises:
-          google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
+            google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
               creation failed for any reason.
+          google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
+              and ``credentials_file`` are passed.
         """
         if channel:
             # Sanity check: Ensure that channel and credentials are not both
@@ -137,12 +162,21 @@ class TextToSpeechGrpcAsyncIOTransport(TextToSpeechTransport):
             self._grpc_channel = type(self).create_channel(
                 host,
                 credentials=credentials,
+                credentials_file=credentials_file,
                 ssl_credentials=ssl_credentials,
-                scopes=self.AUTH_SCOPES,
+                scopes=scopes or self.AUTH_SCOPES,
+                quota_project_id=quota_project_id,
             )
 
         # Run the base constructor.
-        super().__init__(host=host, credentials=credentials)
+        super().__init__(
+            host=host,
+            credentials=credentials,
+            credentials_file=credentials_file,
+            scopes=scopes or self.AUTH_SCOPES,
+            quota_project_id=quota_project_id,
+        )
+
         self._stubs = {}
 
     @property
@@ -156,7 +190,7 @@ class TextToSpeechGrpcAsyncIOTransport(TextToSpeechTransport):
         # have one.
         if not hasattr(self, "_grpc_channel"):
             self._grpc_channel = self.create_channel(
-                self._host, credentials=self._credentials
+                self._host, credentials=self._credentials,
             )
 
         # Return the channel from cache.
@@ -164,7 +198,7 @@ class TextToSpeechGrpcAsyncIOTransport(TextToSpeechTransport):
 
     @property
     def list_voices(
-        self
+        self,
     ) -> Callable[
         [cloud_tts.ListVoicesRequest], Awaitable[cloud_tts.ListVoicesResponse]
     ]:
@@ -192,7 +226,7 @@ class TextToSpeechGrpcAsyncIOTransport(TextToSpeechTransport):
 
     @property
     def synthesize_speech(
-        self
+        self,
     ) -> Callable[
         [cloud_tts.SynthesizeSpeechRequest],
         Awaitable[cloud_tts.SynthesizeSpeechResponse],
