@@ -31,6 +31,7 @@ __protobuf__ = proto.module(
         "VoiceSelectionParams",
         "AudioConfig",
         "SynthesizeSpeechResponse",
+        "Timepoint",
     },
 )
 
@@ -52,7 +53,9 @@ class AudioEncoding(proto.Enum):
     AUDIO_ENCODING_UNSPECIFIED = 0
     LINEAR16 = 1
     MP3 = 2
+    MP3_64_KBPS = 4
     OGG_OPUS = 3
+    MULAW = 5
 
 
 class ListVoicesRequest(proto.Message):
@@ -67,8 +70,8 @@ class ListVoicesRequest(proto.Message):
             return voices that can be used to synthesize this
             language_code. E.g. when specifying "en-NZ", you will get
             supported "en-\*" voices; when specifying "no", you will get
-            supported "no-\*" (Norwegian) and "nb-*" (Norwegian Bokmal)
-            voices; specifying "zh" will also get supported "cmn-*"
+            supported "no-\*" (Norwegian) and "nb-\*" (Norwegian Bokmal)
+            voices; specifying "zh" will also get supported "cmn-\*"
             voices; specifying "zh-hk" will also get supported "yue-\*"
             voices.
     """
@@ -84,7 +87,7 @@ class ListVoicesResponse(proto.Message):
             The list of voices.
     """
 
-    voices = proto.RepeatedField(proto.MESSAGE, number=1, message="Voice")
+    voices = proto.RepeatedField(proto.MESSAGE, number=1, message="Voice",)
 
 
 class Voice(proto.Message):
@@ -106,8 +109,11 @@ class Voice(proto.Message):
     """
 
     language_codes = proto.RepeatedField(proto.STRING, number=1)
+
     name = proto.Field(proto.STRING, number=2)
-    ssml_gender = proto.Field(proto.ENUM, number=3, enum="SsmlVoiceGender")
+
+    ssml_gender = proto.Field(proto.ENUM, number=3, enum="SsmlVoiceGender",)
+
     natural_sample_rate_hertz = proto.Field(proto.INT32, number=4)
 
 
@@ -125,11 +131,27 @@ class SynthesizeSpeechRequest(proto.Message):
         audio_config (~.cloud_tts.AudioConfig):
             Required. The configuration of the
             synthesized audio.
+        enable_time_pointing (Sequence[~.cloud_tts.SynthesizeSpeechRequest.TimepointType]):
+            Whether and what timepoints should be
+            returned in the response.
     """
 
-    input = proto.Field(proto.MESSAGE, number=1, message="SynthesisInput")
-    voice = proto.Field(proto.MESSAGE, number=2, message="VoiceSelectionParams")
-    audio_config = proto.Field(proto.MESSAGE, number=3, message="AudioConfig")
+    class TimepointType(proto.Enum):
+        r"""The type of timepoint information that is returned in the
+        response.
+        """
+        TIMEPOINT_TYPE_UNSPECIFIED = 0
+        SSML_MARK = 1
+
+    input = proto.Field(proto.MESSAGE, number=1, message="SynthesisInput",)
+
+    voice = proto.Field(proto.MESSAGE, number=2, message="VoiceSelectionParams",)
+
+    audio_config = proto.Field(proto.MESSAGE, number=3, message="AudioConfig",)
+
+    enable_time_pointing = proto.RepeatedField(
+        proto.ENUM, number=4, enum=TimepointType,
+    )
 
 
 class SynthesisInput(proto.Message):
@@ -149,8 +171,9 @@ class SynthesisInput(proto.Message):
             `SSML <https://cloud.google.com/text-to-speech/docs/ssml>`__.
     """
 
-    text = proto.Field(proto.STRING, number=1)
-    ssml = proto.Field(proto.STRING, number=2)
+    text = proto.Field(proto.STRING, number=1, oneof="input_source")
+
+    ssml = proto.Field(proto.STRING, number=2, oneof="input_source")
 
 
 class VoiceSelectionParams(proto.Message):
@@ -186,8 +209,10 @@ class VoiceSelectionParams(proto.Message):
     """
 
     language_code = proto.Field(proto.STRING, number=1)
+
     name = proto.Field(proto.STRING, number=2)
-    ssml_gender = proto.Field(proto.ENUM, number=3, enum="SsmlVoiceGender")
+
+    ssml_gender = proto.Field(proto.ENUM, number=3, enum="SsmlVoiceGender",)
 
 
 class AudioConfig(proto.Message):
@@ -237,11 +262,16 @@ class AudioConfig(proto.Message):
             for current supported profile ids.
     """
 
-    audio_encoding = proto.Field(proto.ENUM, number=1, enum="AudioEncoding")
+    audio_encoding = proto.Field(proto.ENUM, number=1, enum="AudioEncoding",)
+
     speaking_rate = proto.Field(proto.DOUBLE, number=2)
+
     pitch = proto.Field(proto.DOUBLE, number=3)
+
     volume_gain_db = proto.Field(proto.DOUBLE, number=4)
+
     sample_rate_hertz = proto.Field(proto.INT32, number=5)
+
     effects_profile_id = proto.RepeatedField(proto.STRING, number=6)
 
 
@@ -257,9 +287,37 @@ class SynthesizeSpeechResponse(proto.Message):
             include the WAV header. Note: as with all bytes fields,
             protobuffers use a pure binary representation, whereas JSON
             representations use base64.
+        timepoints (Sequence[~.cloud_tts.Timepoint]):
+            A link between a position in the original request input and
+            a corresponding time in the output audio. It's only
+            supported via ``<mark>`` of SSML input.
+        audio_config (~.cloud_tts.AudioConfig):
+            The audio metadata of ``audio_content``.
     """
 
     audio_content = proto.Field(proto.BYTES, number=1)
 
+    timepoints = proto.RepeatedField(proto.MESSAGE, number=2, message="Timepoint",)
+
+    audio_config = proto.Field(proto.MESSAGE, number=4, message=AudioConfig,)
+
+
+class Timepoint(proto.Message):
+    r"""This contains a mapping between a certain point in the input
+    text and a corresponding time in the output audio.
+
+    Attributes:
+        mark_name (str):
+            Timepoint name as received from the client within ``<mark>``
+            tag.
+        time_seconds (float):
+            Time offset in seconds from the start of the
+            synthesized audio.
+    """
+
+    mark_name = proto.Field(proto.STRING, number=4)
+
+    time_seconds = proto.Field(proto.DOUBLE, number=3)
+
 
 __all__ = tuple(sorted(__protobuf__.manifest))
