@@ -22,9 +22,11 @@ import grpc
 from grpc.experimental import aio
 import math
 import pytest
+from proto.marshal.rules.dates import DurationRule, TimestampRule
 
 from google import auth
 from google.api_core import client_options
+from google.api_core import exceptions
 from google.api_core import grpc_helpers
 from google.api_core import grpc_helpers_async
 from google.auth import credentials
@@ -42,6 +44,17 @@ def client_cert_source_callback():
     return b"cert bytes", b"key bytes"
 
 
+# If default endpoint is localhost, then default mtls endpoint will be the same.
+# This method modifies the default endpoint so the client can produce a different
+# mtls endpoint for endpoint testing purposes.
+def modify_default_endpoint(client):
+    return (
+        "foo.googleapis.com"
+        if ("localhost" in client.DEFAULT_ENDPOINT)
+        else client.DEFAULT_ENDPOINT
+    )
+
+
 def test__get_default_mtls_endpoint():
     api_endpoint = "example.googleapis.com"
     api_mtls_endpoint = "example.mtls.googleapis.com"
@@ -103,6 +116,14 @@ def test_text_to_speech_client_get_transport_class():
         ),
     ],
 )
+@mock.patch.object(
+    TextToSpeechClient, "DEFAULT_ENDPOINT", modify_default_endpoint(TextToSpeechClient)
+)
+@mock.patch.object(
+    TextToSpeechAsyncClient,
+    "DEFAULT_ENDPOINT",
+    modify_default_endpoint(TextToSpeechAsyncClient),
+)
 def test_text_to_speech_client_client_options(
     client_class, transport_class, transport_name
 ):
@@ -123,95 +144,186 @@ def test_text_to_speech_client_client_options(
         patched.return_value = None
         client = client_class(client_options=options)
         patched.assert_called_once_with(
+            credentials=None,
+            credentials_file=None,
+            host="squid.clam.whelk",
+            scopes=None,
             api_mtls_endpoint="squid.clam.whelk",
             client_cert_source=None,
-            credentials=None,
-            host="squid.clam.whelk",
+            quota_project_id=None,
         )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS is
     # "never".
-    os.environ["GOOGLE_API_USE_MTLS"] = "never"
-    with mock.patch.object(transport_class, "__init__") as patched:
-        patched.return_value = None
-        client = client_class()
-        patched.assert_called_once_with(
-            api_mtls_endpoint=client.DEFAULT_ENDPOINT,
-            client_cert_source=None,
-            credentials=None,
-            host=client.DEFAULT_ENDPOINT,
-        )
+    with mock.patch.dict(os.environ, {"GOOGLE_API_USE_MTLS": "never"}):
+        with mock.patch.object(transport_class, "__init__") as patched:
+            patched.return_value = None
+            client = client_class()
+            patched.assert_called_once_with(
+                credentials=None,
+                credentials_file=None,
+                host=client.DEFAULT_ENDPOINT,
+                scopes=None,
+                api_mtls_endpoint=client.DEFAULT_ENDPOINT,
+                client_cert_source=None,
+                quota_project_id=None,
+            )
 
     # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS is
     # "always".
-    os.environ["GOOGLE_API_USE_MTLS"] = "always"
-    with mock.patch.object(transport_class, "__init__") as patched:
-        patched.return_value = None
-        client = client_class()
-        patched.assert_called_once_with(
-            api_mtls_endpoint=client.DEFAULT_MTLS_ENDPOINT,
-            client_cert_source=None,
-            credentials=None,
-            host=client.DEFAULT_MTLS_ENDPOINT,
-        )
+    with mock.patch.dict(os.environ, {"GOOGLE_API_USE_MTLS": "always"}):
+        with mock.patch.object(transport_class, "__init__") as patched:
+            patched.return_value = None
+            client = client_class()
+            patched.assert_called_once_with(
+                credentials=None,
+                credentials_file=None,
+                host=client.DEFAULT_MTLS_ENDPOINT,
+                scopes=None,
+                api_mtls_endpoint=client.DEFAULT_MTLS_ENDPOINT,
+                client_cert_source=None,
+                quota_project_id=None,
+            )
 
     # Check the case api_endpoint is not provided, GOOGLE_API_USE_MTLS is
     # "auto", and client_cert_source is provided.
-    os.environ["GOOGLE_API_USE_MTLS"] = "auto"
-    options = client_options.ClientOptions(
-        client_cert_source=client_cert_source_callback
-    )
+    with mock.patch.dict(os.environ, {"GOOGLE_API_USE_MTLS": "auto"}):
+        options = client_options.ClientOptions(
+            client_cert_source=client_cert_source_callback
+        )
+        with mock.patch.object(transport_class, "__init__") as patched:
+            patched.return_value = None
+            client = client_class(client_options=options)
+            patched.assert_called_once_with(
+                credentials=None,
+                credentials_file=None,
+                host=client.DEFAULT_MTLS_ENDPOINT,
+                scopes=None,
+                api_mtls_endpoint=client.DEFAULT_MTLS_ENDPOINT,
+                client_cert_source=client_cert_source_callback,
+                quota_project_id=None,
+            )
+
+    # Check the case api_endpoint is not provided, GOOGLE_API_USE_MTLS is
+    # "auto", and default_client_cert_source is provided.
+    with mock.patch.dict(os.environ, {"GOOGLE_API_USE_MTLS": "auto"}):
+        with mock.patch.object(transport_class, "__init__") as patched:
+            with mock.patch(
+                "google.auth.transport.mtls.has_default_client_cert_source",
+                return_value=True,
+            ):
+                patched.return_value = None
+                client = client_class()
+                patched.assert_called_once_with(
+                    credentials=None,
+                    credentials_file=None,
+                    host=client.DEFAULT_MTLS_ENDPOINT,
+                    scopes=None,
+                    api_mtls_endpoint=client.DEFAULT_MTLS_ENDPOINT,
+                    client_cert_source=None,
+                    quota_project_id=None,
+                )
+
+    # Check the case api_endpoint is not provided, GOOGLE_API_USE_MTLS is
+    # "auto", but client_cert_source and default_client_cert_source are None.
+    with mock.patch.dict(os.environ, {"GOOGLE_API_USE_MTLS": "auto"}):
+        with mock.patch.object(transport_class, "__init__") as patched:
+            with mock.patch(
+                "google.auth.transport.mtls.has_default_client_cert_source",
+                return_value=False,
+            ):
+                patched.return_value = None
+                client = client_class()
+                patched.assert_called_once_with(
+                    credentials=None,
+                    credentials_file=None,
+                    host=client.DEFAULT_ENDPOINT,
+                    scopes=None,
+                    api_mtls_endpoint=client.DEFAULT_ENDPOINT,
+                    client_cert_source=None,
+                    quota_project_id=None,
+                )
+
+    # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS has
+    # unsupported value.
+    with mock.patch.dict(os.environ, {"GOOGLE_API_USE_MTLS": "Unsupported"}):
+        with pytest.raises(MutualTLSChannelError):
+            client = client_class()
+
+    # Check the case quota_project_id is provided
+    options = client_options.ClientOptions(quota_project_id="octopus")
     with mock.patch.object(transport_class, "__init__") as patched:
         patched.return_value = None
         client = client_class(client_options=options)
         patched.assert_called_once_with(
-            api_mtls_endpoint=client.DEFAULT_MTLS_ENDPOINT,
-            client_cert_source=client_cert_source_callback,
             credentials=None,
-            host=client.DEFAULT_MTLS_ENDPOINT,
+            credentials_file=None,
+            host=client.DEFAULT_ENDPOINT,
+            scopes=None,
+            api_mtls_endpoint=client.DEFAULT_ENDPOINT,
+            client_cert_source=None,
+            quota_project_id="octopus",
         )
 
-    # Check the case api_endpoint is not provided, GOOGLE_API_USE_MTLS is
-    # "auto", and default_client_cert_source is provided.
-    os.environ["GOOGLE_API_USE_MTLS"] = "auto"
+
+@pytest.mark.parametrize(
+    "client_class,transport_class,transport_name",
+    [
+        (TextToSpeechClient, transports.TextToSpeechGrpcTransport, "grpc"),
+        (
+            TextToSpeechAsyncClient,
+            transports.TextToSpeechGrpcAsyncIOTransport,
+            "grpc_asyncio",
+        ),
+    ],
+)
+def test_text_to_speech_client_client_options_scopes(
+    client_class, transport_class, transport_name
+):
+    # Check the case scopes are provided.
+    options = client_options.ClientOptions(scopes=["1", "2"],)
     with mock.patch.object(transport_class, "__init__") as patched:
-        with mock.patch(
-            "google.auth.transport.mtls.has_default_client_cert_source",
-            return_value=True,
-        ):
-            patched.return_value = None
-            client = client_class()
-            patched.assert_called_once_with(
-                api_mtls_endpoint=client.DEFAULT_MTLS_ENDPOINT,
-                client_cert_source=None,
-                credentials=None,
-                host=client.DEFAULT_MTLS_ENDPOINT,
-            )
+        patched.return_value = None
+        client = client_class(client_options=options)
+        patched.assert_called_once_with(
+            credentials=None,
+            credentials_file=None,
+            host=client.DEFAULT_ENDPOINT,
+            scopes=["1", "2"],
+            api_mtls_endpoint=client.DEFAULT_ENDPOINT,
+            client_cert_source=None,
+            quota_project_id=None,
+        )
 
-    # Check the case api_endpoint is not provided, GOOGLE_API_USE_MTLS is
-    # "auto", but client_cert_source and default_client_cert_source are None.
-    os.environ["GOOGLE_API_USE_MTLS"] = "auto"
+
+@pytest.mark.parametrize(
+    "client_class,transport_class,transport_name",
+    [
+        (TextToSpeechClient, transports.TextToSpeechGrpcTransport, "grpc"),
+        (
+            TextToSpeechAsyncClient,
+            transports.TextToSpeechGrpcAsyncIOTransport,
+            "grpc_asyncio",
+        ),
+    ],
+)
+def test_text_to_speech_client_client_options_credentials_file(
+    client_class, transport_class, transport_name
+):
+    # Check the case credentials file is provided.
+    options = client_options.ClientOptions(credentials_file="credentials.json")
     with mock.patch.object(transport_class, "__init__") as patched:
-        with mock.patch(
-            "google.auth.transport.mtls.has_default_client_cert_source",
-            return_value=False,
-        ):
-            patched.return_value = None
-            client = client_class()
-            patched.assert_called_once_with(
-                api_mtls_endpoint=client.DEFAULT_ENDPOINT,
-                client_cert_source=None,
-                credentials=None,
-                host=client.DEFAULT_ENDPOINT,
-            )
-
-    # Check the case api_endpoint is not provided and GOOGLE_API_USE_MTLS has
-    # unsupported value.
-    os.environ["GOOGLE_API_USE_MTLS"] = "Unsupported"
-    with pytest.raises(MutualTLSChannelError):
-        client = client_class()
-
-    del os.environ["GOOGLE_API_USE_MTLS"]
+        patched.return_value = None
+        client = client_class(client_options=options)
+        patched.assert_called_once_with(
+            credentials=None,
+            credentials_file="credentials.json",
+            host=client.DEFAULT_ENDPOINT,
+            scopes=None,
+            api_mtls_endpoint=client.DEFAULT_ENDPOINT,
+            client_cert_source=None,
+            quota_project_id=None,
+        )
 
 
 def test_text_to_speech_client_client_options_from_dict():
@@ -221,21 +333,24 @@ def test_text_to_speech_client_client_options_from_dict():
         grpc_transport.return_value = None
         client = TextToSpeechClient(client_options={"api_endpoint": "squid.clam.whelk"})
         grpc_transport.assert_called_once_with(
+            credentials=None,
+            credentials_file=None,
+            host="squid.clam.whelk",
+            scopes=None,
             api_mtls_endpoint="squid.clam.whelk",
             client_cert_source=None,
-            credentials=None,
-            host="squid.clam.whelk",
+            quota_project_id=None,
         )
 
 
-def test_list_voices(transport: str = "grpc"):
+def test_list_voices(transport: str = "grpc", request_type=cloud_tts.ListVoicesRequest):
     client = TextToSpeechClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport
+        credentials=credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
     # and we are mocking out the actual API, so just send an empty request.
-    request = cloud_tts.ListVoicesRequest()
+    request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client._transport.list_voices), "__call__") as call:
@@ -248,16 +363,20 @@ def test_list_voices(transport: str = "grpc"):
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
 
-        assert args[0] == request
+        assert args[0] == cloud_tts.ListVoicesRequest()
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, cloud_tts.ListVoicesResponse)
 
 
+def test_list_voices_from_dict():
+    test_list_voices(request_type=dict)
+
+
 @pytest.mark.asyncio
 async def test_list_voices_async(transport: str = "grpc_asyncio"):
     client = TextToSpeechAsyncClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport
+        credentials=credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -286,7 +405,7 @@ async def test_list_voices_async(transport: str = "grpc_asyncio"):
 
 
 def test_list_voices_flattened():
-    client = TextToSpeechClient(credentials=credentials.AnonymousCredentials())
+    client = TextToSpeechClient(credentials=credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(type(client._transport.list_voices), "__call__") as call:
@@ -295,29 +414,30 @@ def test_list_voices_flattened():
 
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
-        client.list_voices(language_code="language_code_value")
+        client.list_voices(language_code="language_code_value",)
 
         # Establish that the underlying call was made with the expected
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
+
         assert args[0].language_code == "language_code_value"
 
 
 def test_list_voices_flattened_error():
-    client = TextToSpeechClient(credentials=credentials.AnonymousCredentials())
+    client = TextToSpeechClient(credentials=credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
         client.list_voices(
-            cloud_tts.ListVoicesRequest(), language_code="language_code_value"
+            cloud_tts.ListVoicesRequest(), language_code="language_code_value",
         )
 
 
 @pytest.mark.asyncio
 async def test_list_voices_flattened_async():
-    client = TextToSpeechAsyncClient(credentials=credentials.AnonymousCredentials())
+    client = TextToSpeechAsyncClient(credentials=credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -331,35 +451,38 @@ async def test_list_voices_flattened_async():
         )
         # Call the method with a truthy value for each flattened field,
         # using the keyword arguments to the method.
-        response = await client.list_voices(language_code="language_code_value")
+        response = await client.list_voices(language_code="language_code_value",)
 
         # Establish that the underlying call was made with the expected
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
+
         assert args[0].language_code == "language_code_value"
 
 
 @pytest.mark.asyncio
 async def test_list_voices_flattened_error_async():
-    client = TextToSpeechAsyncClient(credentials=credentials.AnonymousCredentials())
+    client = TextToSpeechAsyncClient(credentials=credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
     with pytest.raises(ValueError):
         await client.list_voices(
-            cloud_tts.ListVoicesRequest(), language_code="language_code_value"
+            cloud_tts.ListVoicesRequest(), language_code="language_code_value",
         )
 
 
-def test_synthesize_speech(transport: str = "grpc"):
+def test_synthesize_speech(
+    transport: str = "grpc", request_type=cloud_tts.SynthesizeSpeechRequest
+):
     client = TextToSpeechClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport
+        credentials=credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
     # and we are mocking out the actual API, so just send an empty request.
-    request = cloud_tts.SynthesizeSpeechRequest()
+    request = request_type()
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -367,7 +490,7 @@ def test_synthesize_speech(transport: str = "grpc"):
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = cloud_tts.SynthesizeSpeechResponse(
-            audio_content=b"audio_content_blob"
+            audio_content=b"audio_content_blob",
         )
 
         response = client.synthesize_speech(request)
@@ -376,17 +499,22 @@ def test_synthesize_speech(transport: str = "grpc"):
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
 
-        assert args[0] == request
+        assert args[0] == cloud_tts.SynthesizeSpeechRequest()
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, cloud_tts.SynthesizeSpeechResponse)
+
     assert response.audio_content == b"audio_content_blob"
 
 
+def test_synthesize_speech_from_dict():
+    test_synthesize_speech(request_type=dict)
+
+
 @pytest.mark.asyncio
 async def test_synthesize_speech_async(transport: str = "grpc_asyncio"):
     client = TextToSpeechAsyncClient(
-        credentials=credentials.AnonymousCredentials(), transport=transport
+        credentials=credentials.AnonymousCredentials(), transport=transport,
     )
 
     # Everything is optional in proto3 as far as the runtime is concerned,
@@ -399,7 +527,7 @@ async def test_synthesize_speech_async(transport: str = "grpc_asyncio"):
     ) as call:
         # Designate an appropriate return value for the call.
         call.return_value = grpc_helpers_async.FakeUnaryUnaryCall(
-            cloud_tts.SynthesizeSpeechResponse(audio_content=b"audio_content_blob")
+            cloud_tts.SynthesizeSpeechResponse(audio_content=b"audio_content_blob",)
         )
 
         response = await client.synthesize_speech(request)
@@ -412,11 +540,12 @@ async def test_synthesize_speech_async(transport: str = "grpc_asyncio"):
 
     # Establish that the response is the type that we expect.
     assert isinstance(response, cloud_tts.SynthesizeSpeechResponse)
+
     assert response.audio_content == b"audio_content_blob"
 
 
 def test_synthesize_speech_flattened():
-    client = TextToSpeechClient(credentials=credentials.AnonymousCredentials())
+    client = TextToSpeechClient(credentials=credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -439,17 +568,20 @@ def test_synthesize_speech_flattened():
         # request object values.
         assert len(call.mock_calls) == 1
         _, args, _ = call.mock_calls[0]
+
         assert args[0].input == cloud_tts.SynthesisInput(text="text_value")
+
         assert args[0].voice == cloud_tts.VoiceSelectionParams(
             language_code="language_code_value"
         )
+
         assert args[0].audio_config == cloud_tts.AudioConfig(
             audio_encoding=cloud_tts.AudioEncoding.LINEAR16
         )
 
 
 def test_synthesize_speech_flattened_error():
-    client = TextToSpeechClient(credentials=credentials.AnonymousCredentials())
+    client = TextToSpeechClient(credentials=credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -466,7 +598,7 @@ def test_synthesize_speech_flattened_error():
 
 @pytest.mark.asyncio
 async def test_synthesize_speech_flattened_async():
-    client = TextToSpeechAsyncClient(credentials=credentials.AnonymousCredentials())
+    client = TextToSpeechAsyncClient(credentials=credentials.AnonymousCredentials(),)
 
     # Mock the actual call within the gRPC stub, and fake the request.
     with mock.patch.object(
@@ -492,10 +624,13 @@ async def test_synthesize_speech_flattened_async():
         # request object values.
         assert len(call.mock_calls)
         _, args, _ = call.mock_calls[0]
+
         assert args[0].input == cloud_tts.SynthesisInput(text="text_value")
+
         assert args[0].voice == cloud_tts.VoiceSelectionParams(
             language_code="language_code_value"
         )
+
         assert args[0].audio_config == cloud_tts.AudioConfig(
             audio_encoding=cloud_tts.AudioEncoding.LINEAR16
         )
@@ -503,7 +638,7 @@ async def test_synthesize_speech_flattened_async():
 
 @pytest.mark.asyncio
 async def test_synthesize_speech_flattened_error_async():
-    client = TextToSpeechAsyncClient(credentials=credentials.AnonymousCredentials())
+    client = TextToSpeechAsyncClient(credentials=credentials.AnonymousCredentials(),)
 
     # Attempting to call a method with both a request object and flattened
     # fields is an error.
@@ -521,18 +656,37 @@ async def test_synthesize_speech_flattened_error_async():
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.TextToSpeechGrpcTransport(
-        credentials=credentials.AnonymousCredentials()
+        credentials=credentials.AnonymousCredentials(),
     )
     with pytest.raises(ValueError):
         client = TextToSpeechClient(
-            credentials=credentials.AnonymousCredentials(), transport=transport
+            credentials=credentials.AnonymousCredentials(), transport=transport,
+        )
+
+    # It is an error to provide a credentials file and a transport instance.
+    transport = transports.TextToSpeechGrpcTransport(
+        credentials=credentials.AnonymousCredentials(),
+    )
+    with pytest.raises(ValueError):
+        client = TextToSpeechClient(
+            client_options={"credentials_file": "credentials.json"},
+            transport=transport,
+        )
+
+    # It is an error to provide scopes and a transport instance.
+    transport = transports.TextToSpeechGrpcTransport(
+        credentials=credentials.AnonymousCredentials(),
+    )
+    with pytest.raises(ValueError):
+        client = TextToSpeechClient(
+            client_options={"scopes": ["1", "2"]}, transport=transport,
         )
 
 
 def test_transport_instance():
     # A client may be instantiated with a custom transport instance.
     transport = transports.TextToSpeechGrpcTransport(
-        credentials=credentials.AnonymousCredentials()
+        credentials=credentials.AnonymousCredentials(),
     )
     client = TextToSpeechClient(transport=transport)
     assert client._transport is transport
@@ -541,13 +695,13 @@ def test_transport_instance():
 def test_transport_get_channel():
     # A client may be instantiated with a custom transport instance.
     transport = transports.TextToSpeechGrpcTransport(
-        credentials=credentials.AnonymousCredentials()
+        credentials=credentials.AnonymousCredentials(),
     )
     channel = transport.grpc_channel
     assert channel
 
     transport = transports.TextToSpeechGrpcAsyncIOTransport(
-        credentials=credentials.AnonymousCredentials()
+        credentials=credentials.AnonymousCredentials(),
     )
     channel = transport.grpc_channel
     assert channel
@@ -555,31 +709,67 @@ def test_transport_get_channel():
 
 def test_transport_grpc_default():
     # A client should use the gRPC transport by default.
-    client = TextToSpeechClient(credentials=credentials.AnonymousCredentials())
-    assert isinstance(client._transport, transports.TextToSpeechGrpcTransport)
+    client = TextToSpeechClient(credentials=credentials.AnonymousCredentials(),)
+    assert isinstance(client._transport, transports.TextToSpeechGrpcTransport,)
+
+
+def test_text_to_speech_base_transport_error():
+    # Passing both a credentials object and credentials_file should raise an error
+    with pytest.raises(exceptions.DuplicateCredentialArgs):
+        transport = transports.TextToSpeechTransport(
+            credentials=credentials.AnonymousCredentials(),
+            credentials_file="credentials.json",
+        )
 
 
 def test_text_to_speech_base_transport():
     # Instantiate the base transport.
-    transport = transports.TextToSpeechTransport(
-        credentials=credentials.AnonymousCredentials()
-    )
+    with mock.patch(
+        "google.cloud.texttospeech_v1beta1.services.text_to_speech.transports.TextToSpeechTransport.__init__"
+    ) as Transport:
+        Transport.return_value = None
+        transport = transports.TextToSpeechTransport(
+            credentials=credentials.AnonymousCredentials(),
+        )
 
     # Every method on the transport should just blindly
     # raise NotImplementedError.
-    methods = ("list_voices", "synthesize_speech")
+    methods = (
+        "list_voices",
+        "synthesize_speech",
+    )
     for method in methods:
         with pytest.raises(NotImplementedError):
             getattr(transport, method)(request=object())
 
 
+def test_text_to_speech_base_transport_with_credentials_file():
+    # Instantiate the base transport with a credentials file
+    with mock.patch.object(
+        auth, "load_credentials_from_file"
+    ) as load_creds, mock.patch(
+        "google.cloud.texttospeech_v1beta1.services.text_to_speech.transports.TextToSpeechTransport._prep_wrapped_messages"
+    ) as Transport:
+        Transport.return_value = None
+        load_creds.return_value = (credentials.AnonymousCredentials(), None)
+        transport = transports.TextToSpeechTransport(
+            credentials_file="credentials.json", quota_project_id="octopus",
+        )
+        load_creds.assert_called_once_with(
+            "credentials.json",
+            scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            quota_project_id="octopus",
+        )
+
+
 def test_text_to_speech_auth_adc():
     # If no credentials are provided, we should use ADC credentials.
     with mock.patch.object(auth, "default") as adc:
         adc.return_value = (credentials.AnonymousCredentials(), None)
         TextToSpeechClient()
         adc.assert_called_once_with(
-            scopes=("https://www.googleapis.com/auth/cloud-platform",)
+            scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            quota_project_id=None,
         )
 
 
@@ -588,9 +778,12 @@ def test_text_to_speech_transport_auth_adc():
     # ADC credentials.
     with mock.patch.object(auth, "default") as adc:
         adc.return_value = (credentials.AnonymousCredentials(), None)
-        transports.TextToSpeechGrpcTransport(host="squid.clam.whelk")
+        transports.TextToSpeechGrpcTransport(
+            host="squid.clam.whelk", quota_project_id="octopus"
+        )
         adc.assert_called_once_with(
-            scopes=("https://www.googleapis.com/auth/cloud-platform",)
+            scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            quota_project_id="octopus",
         )
 
 
@@ -675,8 +868,10 @@ def test_text_to_speech_grpc_transport_channel_mtls_with_client_cert_source(
     grpc_create_channel.assert_called_once_with(
         "mtls.squid.clam.whelk:443",
         credentials=mock_cred,
-        ssl_credentials=mock_ssl_cred,
+        credentials_file=None,
         scopes=("https://www.googleapis.com/auth/cloud-platform",),
+        ssl_credentials=mock_ssl_cred,
+        quota_project_id=None,
     )
     assert transport.grpc_channel == mock_grpc_channel
 
@@ -708,8 +903,10 @@ def test_text_to_speech_grpc_asyncio_transport_channel_mtls_with_client_cert_sou
     grpc_create_channel.assert_called_once_with(
         "mtls.squid.clam.whelk:443",
         credentials=mock_cred,
-        ssl_credentials=mock_ssl_cred,
+        credentials_file=None,
         scopes=("https://www.googleapis.com/auth/cloud-platform",),
+        ssl_credentials=mock_ssl_cred,
+        quota_project_id=None,
     )
     assert transport.grpc_channel == mock_grpc_channel
 
@@ -743,8 +940,10 @@ def test_text_to_speech_grpc_transport_channel_mtls_with_adc(
         grpc_create_channel.assert_called_once_with(
             "mtls.squid.clam.whelk:443",
             credentials=mock_cred,
-            ssl_credentials=mock_ssl_cred,
+            credentials_file=None,
             scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            ssl_credentials=mock_ssl_cred,
+            quota_project_id=None,
         )
         assert transport.grpc_channel == mock_grpc_channel
 
@@ -778,7 +977,9 @@ def test_text_to_speech_grpc_asyncio_transport_channel_mtls_with_adc(
         grpc_create_channel.assert_called_once_with(
             "mtls.squid.clam.whelk:443",
             credentials=mock_cred,
-            ssl_credentials=mock_ssl_cred,
+            credentials_file=None,
             scopes=("https://www.googleapis.com/auth/cloud-platform",),
+            ssl_credentials=mock_ssl_cred,
+            quota_project_id=None,
         )
         assert transport.grpc_channel == mock_grpc_channel
